@@ -29,13 +29,13 @@
 #include <kstandarddirs.h>
 
 #include <qstring.h>
-#include <qvaluelist.h>
+
 
 using namespace bt;
 
 namespace kt
 {	
-	Uint32 AntiP2P::toUint32(QString& ip)
+	Uint32 AntiP2P::toUint32(const QString& ip)
 	{
 		bool test;
 		Uint32 ret = ip.section('.',0,0).toULongLong(&test);
@@ -90,7 +90,7 @@ namespace kt
 	void AntiP2P::load()
 	{
 		file = new MMapFile();
-		if(! file->open(KGlobal::dirs()->saveLocation("data","ktorrent") + "level1.dat", MMapFile::READ) )
+		if(! file->open(KGlobal::dirs()->saveLocation("data","ktorrent") + "level1.dat", QIODevice::ReadOnly) )
 		{
 			Out(SYS_IPF|LOG_NOTICE) << "Anti-p2p file not loaded." << endl;
 			file = 0;
@@ -141,7 +141,7 @@ namespace kt
 		return file != 0;
 	}
 	
-	bool AntiP2P::isBlockedIP( QString& ip )
+	bool AntiP2P::isBlockedIP(const QString& ip )
 	{
 		Uint32 test = toUint32(ip);
 		return isBlockedIP(test);
