@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
+ *   Copyright (C) 2005-2007 by Joris Guisson                              *
  *   joris.guisson@gmail.com                                               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,18 +15,19 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #ifndef BTSEARCHWIDGET_H
 #define BTSEARCHWIDGET_H
 
 #include <qwidget.h>
-#include <qvaluevector.h>
 #include <kurl.h>
+#include <ktoolbar.h>
+#include <klineedit.h>
 
-class SearchBar;
-class KProgress;
-class KPopupMenu;
+class QProgressBar;
+class KMenu;
+class KComboBox;
 
 namespace KParts
 {
@@ -36,6 +37,7 @@ namespace KParts
 namespace kt
 {
 	class HTMLPart;
+	class SearchWidget;
 	class SearchPlugin;
 	class SearchEngineList;
 	
@@ -52,36 +54,56 @@ namespace kt
 		SearchWidget(SearchPlugin* sp);
 		virtual ~SearchWidget();
 	
-		KPopupMenu* rightClickMenu();
+		KMenu* rightClickMenu();
 		
 		void updateSearchEngines(const SearchEngineList & sl);
+		
+		QString getSearchText() const {return search_text->text();}
+		KUrl getCurrentUrl() const;
+		QString getSearchBarText() const;
+		int getSearchBarEngine() const;
+		
+		bool backAvailable() const;
+		
+	signals:
+		void enableBack(bool on);
+		void openNewTab(const KUrl & url);
 	
 	public slots:
 		void search(const QString & text,int engine = 0);
 		void copy();
+		void find();
+		void search();
+		void back();
+		void reload();
 		void onShutDown();
+		void restore(const KUrl & url,const QString & text,const QString & sb_text,int engine);
 	
 	private slots:
-		void searchPressed();
-		void clearPressed();
-		void onURLHover(const QString & url);
+		void onUrlHover(const QString & url);
 		void onFinished();
-		void onOpenTorrent(const KURL & url);
-		void onSaveTorrent(const KURL & url);
+		void onOpenTorrent(const KUrl & url);
+		void onSaveTorrent(const KUrl & url);
 		void showPopupMenu(const QString & s,const QPoint & p);
 		void onBackAvailable(bool available);
 		void onFrameAdded(KParts::Part* p);
 		void statusBarMsg(const QString & url);
-		void openTorrent(const KURL & url);
+		void openTorrent(const KUrl & url);
 		void loadingProgress(int perc);
+		void openNewTab();
+		
 		
 	private:
 		HTMLPart* html_part;
-		SearchBar* sbar;
-		KPopupMenu* right_click_menu;
-		int back_id;
+		KToolBar* sbar;
+		KMenu* right_click_menu;
 		SearchPlugin* sp;
-		KProgress* prog;
+		QProgressBar* prog;
+		
+		KComboBox* search_engine;
+		KLineEdit* search_text;
+		QAction* open_url_action;
+		KUrl url_to_open;
 	};
 
 }
